@@ -40,6 +40,7 @@ Examples:
 
 import shutil
 from tkinter import N
+from pathlib import Path
 
 from IPython.core import magic_arguments
 from IPython.core.magic import line_magic, Magics, magics_class, needs_local_scope
@@ -55,7 +56,7 @@ class DfMagics(Magics):
     def reset(self):
         self.verbose = False
         self.is_registered = False
-        self.path = '$HOME'
+        self.path = str(Path.cwd())
         self.raw = False
         self.on = False
         self.off = False
@@ -66,7 +67,7 @@ class DfMagics(Magics):
     @magic_arguments.argument('-h', '--help', action='store_true')
     @magic_arguments.argument('--on', action='store_true', help='Turn on persistent df. All the following cells will show the space usage for the partition until turned off.')
     @magic_arguments.argument('--off', action='store_true', help='Turn off persistent df')
-    @magic_arguments.argument('-p', '--path', default='$HOME', help='Sets the path to the partition to check')
+    @magic_arguments.argument('-p', '--path', default=f'{Path.cwd()}', help='Sets the path to the partition to check')
     @magic_arguments.argument('--raw', action='store_true', help="Returns the raw data object.")
     @magic_arguments.argument('-v', '--verbose', action='store_true', help='Prints off additional text for debugging.')
     def df(self, line='', code=None):
